==> centreon-web-23.04.29.tar.gz: centreon-web-23.04.29/src/Core/Infrastructure/Platform/Api/FindInstallationStatus/FindInstallationStatusPresenter.php <==
<?php

/*
 * Copyright 2005 - 2021 Centreon (https://www.centreon.com/)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * For more information : contact@centreon.com
 *
 */

declare(strict_types=1);

namespace Core\Infrastructure\Platform\Api\FindInstallationStatus;

use Core\Application\Common\UseCase\AbstractPresenter;
use Core\Application\Platform\UseCase\FindInstallationStatus\FindInstallationStatusPresenterInterface;
use Core\Application\Platform\UseCase\FindInstallationStatus\FindInstallationStatusResponse;

class FindInstallationStatusPresenter extends AbstractPresenter implements FindInstallationStatusPresenterInterface
{
    /**
     * {@inheritDoc}
     * @param FindInstallationStatusResponse $data
     */
    public function present(mixed $data): void
    {
        $presenterResponse = [
            'is_installed' => $data->isCentreonWebInstalled,
            'has_upgrade_available' => $data->isCentreonWebUpgradeAvailable
        ];

        parent::present($presenterResponse);
    }
}

==> centreon-web-24.04.19.tar.gz: centreon-web-24.04.19/src/Core/Infrastructure/Platform/Api/FindInstallationStatus/FindInstallationStatusPresenter.php <==
<?php

/*
 * Copyright 2005 - 2023 Centreon (https://www.centreon.com/)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * For more information : contact@centreon.com
 *
 */

declare(strict_types=1);

namespace Core\Infrastructure\Platform\Api\FindInstallationStatus;

use Core\Application\Common\UseCase\AbstractPresenter;
use Core\Application\Platform\UseCase\FindInstallationStatus\FindInstallationStatusPresenterInterface;
use Core\Application\Platform\UseCase\FindInstallationStatus\FindInstallationStatusResponse;

class FindInstallationStatusPresenter extends AbstractPresenter implements FindInstallationStatusPresenterInterface
{
    /**
     * {@inheritDoc}
     *
     * @param FindInstallationStatusResponse $data
     */
    public function present(mixed $data): void
    {
        $presenterResponse = [
            'is_installed' => $data->isCentreonWebInstalled,
            'has_upgrade_available' => $data->isCentreonWebUpgradeAvailable,
        ];

        parent::present($presenterResponse);
    }
}
